#!/usr/bin/env bash

#
# This file is part of the eskimo project referenced at www.eskimo.sh. The licensing information below apply just as
# well to this individual file than to the Eskimo Project as a whole.
#
# Copyright 2019 eskimo.sh / https://www.eskimo.sh - All rights reserved.
# Author : eskimo.sh / https://www.eskimo.sh
#
# Eskimo is available under a dual licensing model : commercial and GNU AGPL.
# If you did not acquire a commercial licence for Eskimo, you can still use it and consider it free software under the
# terms of the GNU Affero Public License. You can redistribute it and/or modify it under the terms of the GNU Affero
# Public License  as published by the Free Software Foundation, either version 3 of the License, or (at your option)
# any later version.
# Compliance to each and every aspect of the GNU Affero Public License is mandatory for users who did no acquire a
# commercial license.
#
# Eskimo is distributed as a free software under GNU AGPL in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Affero Public License for more details.
#
# You should have received a copy of the GNU Affero Public License along with Eskimo. If not,
# see <https://www.gnu.org/licenses/> or write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA, 02110-1301 USA.
#
# You can be released from the requirements of the license by purchasing a commercial license. Buying such a
# commercial license is mandatory as soon as :
# - you develop activities involving Eskimo without disclosing the source code of your own product, software,
#   platform, use cases or scripts.
# - you deploy eskimo as part of a commercial product, platform or software.
# For more information, please contact eskimo.sh at https://www.eskimo.sh
#
# The above copyright notice and this licensing notice shall be included in all copies or substantial portions of the
# Software.
#

set -e

echo " - Loading Topology"
. /etc/eskimo_topology.sh

export ELASTICSEARCH_MASTER=`eval echo "\$"$(echo SELF_MASTER_ELASTICSEARCH_$SELF_IP_ADDRESS | tr -d .)`
if [[ $ELASTICSEARCH_MASTER == "" ]]; then
    echo " - No ES master found in topology for $SELF_IP_ADDRESS"
    exit -3
fi

echo " - Adapting Configuration file"

# ES / Kibana 6.x
sed -i s/"#elasticsearch.url: \"http:\/\/localhost:9200\""/"elasticsearch.url: \"http:\/\/$ELASTICSEARCH_MASTER:9200\""/g \
        /usr/local/etc/kibana/kibana.yml

# ES / Kibana 7.x
sed -i s/"#elasticsearch.hosts: \[\"http:\/\/localhost:9200\"\]"/"elasticsearch.hosts: \[\"http:\/\/$ELASTICSEARCH_MASTER:9200\"\]"/g \
        /usr/local/etc/kibana/kibana.yml


# For memory, I need to adapt the node command line in bin/kibana
echo "#/bin/bash" > /tmp/kibana.eskimo

if [[ $MEMORY_KIBANA != "" ]]; then
    echo "export NODE_OPTIONS=\"--max-old-space-size="$MEMORY_KIBANA"\"" >> /tmp/kibana.eskimo
fi

echo "/usr/local/lib/kibana/bin/kibana" >> /tmp/kibana.eskimo

chmod 755 /tmp/kibana.eskimo

